@@ -1,17 +1,19 @@
 """Tasks API calls."""
 from __future__ import annotations
 
+import math
 import tempfile
 import zipfile
 from pathlib import Path
 from typing import Any, Optional, Union
 
+import cv2
 from cvat_sdk.core.helpers import TqdmProgressReporter
 from cvat_sdk.core.proxies.tasks import ResourceType
 from tqdm import tqdm
 
 from .auth import get_client
-from .utils import VALID_IMAGE_FORMATS
+from .utils import VALID_IMAGE_FORMATS, VALID_VIDEO_FORMATS
 
 
 def get_frames_info(task_id: int) -> list[dict[str, Any]]:
@@ -113,6 +115,25 @@ def upload_images(task_id: int, image_directory: Union[str, Path]) -> None:
     upload_image_list(task_id, images)
 
 
+def upload_video(project_id: int, video_path: Union[str, Path]) -> None:
+    """Upload video to a new task."""
+    video_path = Path(video_path)
+    cap = cv2.VideoCapture(str(video_path))
+    n_frames = math.ceil(cap.get(cv2.CAP_PROP_FRAME_COUNT))
+    task = create_task(video_path.name, project_id, segment_size=n_frames + 1)
+    upload_image_list(task["id"], [video_path])
+
+
+def upload_videos(project_id: int, video_directory: Union[str, Path]) -> None:
+    """Upload video from a directory to a set of new tasks (1 per video)."""
+    video_directory = Path(video_directory)
+    videos: list[Path] = []
+    for extension in VALID_VIDEO_FORMATS:
+        videos.extend(video_directory.glob(f"*{extension}"))
+    for video_path in videos:
+        upload_video(project_id, video_path)
+
+
 def upload_image_list(task_id: int, image_list: list[Union[str, Path]]) -> None:
     """Upload a list of images to a task."""
     with get_client() as client:
